@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -73,13 +73,12 @@ static void         instance_set_property( GObject *object, guint property_id, c
 static void         instance_dispose( GObject *object );
 static void         instance_finalize( GObject *object );
 
-static void         object_copy( NAObject *target, const NAObject *source, gboolean recursive );
+static void         object_dump( const NAObject *object );
 static gboolean     object_is_valid( const NAObject *object );
 
 static void         ifactory_object_iface_init( NAIFactoryObjectInterface *iface );
 static guint        ifactory_object_get_version( const NAIFactoryObject *instance );
 static NADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instance );
-static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
@@ -92,7 +91,6 @@ static gboolean     convert_pre_v3_multiple( NAObjectProfile *profile );
 static gboolean     convert_pre_v3_isfiledir( NAObjectProfile *profile );
 static void         read_done_ending( NAObjectProfile *profile );
 static void         split_path_parameters( NAObjectProfile *profile );
-static gboolean     profile_is_valid( const NAObjectProfile *profile );
 static gboolean     is_valid_path_parameters( const NAObjectProfile *profile );
 
 static gchar       *object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent );
@@ -169,9 +167,7 @@ class_init( NAObjectProfileClass *klass )
 	object_class->finalize = instance_finalize;
 
 	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
-	naobject_class->copy = object_copy;
-	naobject_class->are_equal = NULL;
+	naobject_class->dump = object_dump;
 	naobject_class->is_valid = object_is_valid;
 
 	naobjectid_class = NA_OBJECT_ID_CLASS( klass );
@@ -268,24 +264,52 @@ instance_finalize( GObject *object )
 }
 
 static void
-object_copy( NAObject *target, const NAObject *source, gboolean recursive )
+object_dump( const NAObject *object )
 {
-	g_return_if_fail( NA_IS_OBJECT_PROFILE( target ));
-	g_return_if_fail( NA_IS_OBJECT_PROFILE( source ));
+	static const char *thisfn = "na_object_profile_object_dump";
+	NAObjectProfile *self;
 
-	if( !NA_OBJECT_PROFILE( target )->private->dispose_has_run &&
-		!NA_OBJECT_PROFILE( source )->private->dispose_has_run ){
+	g_return_if_fail( NA_IS_OBJECT_PROFILE( object ));
 
-		na_factory_object_copy( NA_IFACTORY_OBJECT( target ), NA_IFACTORY_OBJECT( source ));
+	self = NA_OBJECT_PROFILE( object );
+
+	if( !self->private->dispose_has_run ){
+		g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
+				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->dump ){
+			NA_OBJECT_CLASS( st_parent_class )->dump( object );
+		}
+
+		g_debug( "+- end of dump" );
 	}
 }
 
 static gboolean
 object_is_valid( const NAObject *object )
 {
+	static const gchar *thisfn = "na_object_profile_object_is_valid";
+	gboolean is_valid;
+	NAObjectProfile *profile;
+
 	g_return_val_if_fail( NA_IS_OBJECT_PROFILE( object ), FALSE );
 
-	return( profile_is_valid( NA_OBJECT_PROFILE( object )));
+	is_valid = FALSE;
+	profile = NA_OBJECT_PROFILE( object );
+
+	if( !profile->private->dispose_has_run ){
+		g_debug( "%s: profile=%p (%s)", thisfn, ( void * ) profile, G_OBJECT_TYPE_NAME( profile ));
+
+		is_valid = is_valid_path_parameters( profile );
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->is_valid ){
+			is_valid &= NA_OBJECT_CLASS( st_parent_class )->is_valid( object );
+		}
+	}
+
+	return( is_valid );
 }
 
 static void
@@ -297,12 +321,7 @@ ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
 
 	iface->get_version = ifactory_object_get_version;
 	iface->get_groups = ifactory_object_get_groups;
-	iface->copy = NULL;
-	iface->are_equal = NULL;
-	iface->is_valid = ifactory_object_is_valid;
-	iface->read_start = NULL;
 	iface->read_done = ifactory_object_read_done;
-	iface->write_start = NULL;
 	iface->write_done = ifactory_object_write_done;
 }
 
@@ -318,19 +337,6 @@ ifactory_object_get_groups( const NAIFactoryObject *instance )
 	return( profile_data_groups );
 }
 
-static gboolean
-ifactory_object_is_valid( const NAIFactoryObject *object )
-{
-	static const gchar *thisfn = "na_object_profile_ifactory_object_is_valid: object";
-
-	g_debug( "%s: object=%p (%s)",
-			thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
-	g_return_val_if_fail( NA_IS_OBJECT_PROFILE( object ), FALSE );
-
-	return( profile_is_valid( NA_OBJECT_PROFILE( object )));
-}
-
 static void
 ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
 {
@@ -425,20 +431,28 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
 static gboolean
 convert_pre_v3_parameters( NAObjectProfile *profile )
 {
+	static const gchar *thisfn = "na_object_profile_convert_pre_v3_parameters";
 	gboolean path_changed, parms_changed;
+	gchar *before;
 
 	gchar *path = na_object_get_path( profile );
+	before = g_strdup( path );
 	path_changed = convert_pre_v3_parameters_str( path );
 	if( path_changed ){
 		na_object_set_path( profile, path );
+		g_debug( "%s: path=%s changed to %s", thisfn, before, path );
 	}
+	g_free( before );
 	g_free( path );
 
 	gchar *parms = na_object_get_parameters( profile );
+	before = g_strdup( parms );
 	parms_changed = convert_pre_v3_parameters_str( parms );
 	if( parms_changed ){
 		na_object_set_parameters( profile, parms );
+		g_debug( "%s: parameters=%s changed to %s", thisfn, before, parms );
 	}
+	g_free( before );
 	g_free( parms );
 
 	return( path_changed || parms_changed );
@@ -447,7 +461,6 @@ convert_pre_v3_parameters( NAObjectProfile *profile )
 static gboolean
 convert_pre_v3_parameters_str( gchar *str )
 {
-	static const gchar *thisfn = "na_object_profile_convert_pre_v3_parameters_str";
 	gboolean changed;
 	gchar *iter = str;
 
@@ -456,7 +469,6 @@ convert_pre_v3_parameters_str( gchar *str )
 			strlen( iter ) > 0 &&
 			( iter = g_strstr_len( iter, strlen( iter ), "%" )) != NULL ){
 
-		g_debug( "%s: iter[1]='%c'", thisfn, iter[1] );
 		switch( iter[1] ){
 
 			/* as a special optimization case, "%d/%f" parameters
@@ -518,13 +530,15 @@ convert_pre_v3_parameters_str( gchar *str )
 static gboolean
 convert_pre_v3_multiple( NAObjectProfile *profile )
 {
+	static const gchar *thisfn = "na_object_profile_convert_pre_v3_multiple";
 	gboolean accept_multiple;
 	gchar *selection_count;
 
 	accept_multiple = na_object_is_multiple( profile );
 	selection_count = g_strdup( accept_multiple ? ">0" : "=1" );
 	na_object_set_selection_count( profile, selection_count );
-	g_debug( "na_object_profile_convert_pre_v3_multiple: set selection_count=%s", selection_count );
+	g_debug( "%s: accept_multiple=%s changed to selection_count= %s",
+			thisfn, accept_multiple ? "True":"False", selection_count );
 	g_free( selection_count );
 
 	return( TRUE );
@@ -536,20 +550,32 @@ convert_pre_v3_multiple( NAObjectProfile *profile )
  *             file=true  and dir=true  -> both files and dirs -> all/all
  *
  * we try to replace this with the corresponding mimetype, but only if
- * current mimetype is '*' (or * / * or all/all)
+ * current mimetype is '*' (or * / * or all/all).
+ *
+ * note that inode/directory is actually the mimetype provided by Nautilus;
+ * contrarily all/allfiles mimetype has to be checked separately.
  */
 static gboolean
 convert_pre_v3_isfiledir( NAObjectProfile *profile )
 {
+	static const gchar *thisfn = "na_object_profile_convert_pre_v3_isfiledir";
+	gboolean is_all_mimetypes;
 	gboolean converted;
 	gboolean isfile, isdir;
 	GSList *mimetypes;
+	GSList *before_list;
+	gchar *before_str, *after_str;
 
 	converted = FALSE;
 
-	if( na_icontext_is_all_mimetypes( NA_ICONTEXT( profile ))){
+	na_object_check_mimetypes( profile );
+	is_all_mimetypes = na_object_get_all_mimetypes( profile );
+	g_debug( "%s: is_all_mimetypes=%s", thisfn, is_all_mimetypes ? "True":"False" );
+
+	if( is_all_mimetypes ){
 		converted = TRUE;
 		mimetypes = NULL;
+		before_list = na_object_get_mimetypes( profile );
 
 		isfile = na_object_is_file( profile );
 		isdir = na_object_is_dir( profile );
@@ -573,15 +599,23 @@ convert_pre_v3_isfiledir( NAObjectProfile *profile )
 				/* not files nor dir: this is an invalid case -> do not modify
 				 * mimetypes
 				 */
+				g_warning( "%s: is_dir=False, is_file=False is invalid", thisfn );
 				converted = FALSE;
 			}
 		}
 
 		if( converted ){
 			na_object_set_mimetypes( profile, mimetypes );
+
+			before_str = na_core_utils_slist_join_at_end( before_list, ";" );
+			after_str = na_core_utils_slist_join_at_end( mimetypes, ";" );
+			g_debug( "%s; mimetypes=[%s] changed to [%s]", thisfn, before_str, after_str );
+			g_free( after_str );
+			g_free( before_str );
 		}
 
 		na_core_utils_slist_free( mimetypes );
+		na_core_utils_slist_free( before_list );
 	}
 
 	return( converted );
@@ -625,23 +659,6 @@ split_path_parameters( NAObjectProfile *profile )
 	g_free( path );
 }
 
-static gboolean
-profile_is_valid( const NAObjectProfile *profile )
-{
-	gboolean is_valid;
-
-	is_valid = FALSE;
-
-	if( !profile->private->dispose_has_run ){
-
-		is_valid = \
-				is_valid_path_parameters( profile ) &&
-				na_icontext_is_valid( NA_ICONTEXT( profile ));
-	}
-
-	return( is_valid );
-}
-
 /*
  * historical behavior was to not check path nor parameters at all
  * 2.29.x serie, and up to 2.30.0, have tried to check an actual executable path
