@@ -42,10 +42,9 @@
 #include <core/na-iprefs.h>
 
 #include "nact-application.h"
-#include "nact-iprefs.h"
-#include "nact-iactions-list.h"
 #include "nact-assistant-import.h"
 #include "nact-main-window.h"
+#include "nact-tree-ieditable.h"
 
 /* Import Assistant
  *
@@ -68,19 +67,22 @@ enum {
 
 /* private class data
  */
-struct NactAssistantImportClassPrivate {
+struct _NactAssistantImportClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NactAssistantImportPrivate {
+struct _NactAssistantImportPrivate {
 	gboolean     dispose_has_run;
-	GConfClient *gconf;
 	GList       *results;
 };
 
-static BaseAssistantClass *st_parent_class = NULL;
+static const gchar        *st_xmlui_filename = PKGDATADIR "/nautilus-actions-config-tool.ui";
+static const gchar        *st_toplevel_name  = "ImportAssistant";
+static const gchar        *st_wsp_name       = NA_IPREFS_IMPORT_ASSISTANT_WSP;
+
+static BaseAssistantClass *st_parent_class   = NULL;
 
 static GType         register_type( void );
 static void          class_init( NactAssistantImportClass *klass );
@@ -88,13 +90,7 @@ static void          instance_init( GTypeInstance *instance, gpointer klass );
 static void          instance_dispose( GObject *application );
 static void          instance_finalize( GObject *application );
 
-static NactAssistantImport *assist_new( BaseWindow *parent );
-
-static gchar        *window_get_iprefs_window_id( const BaseWindow *window );
-static gchar        *window_get_dialog_name( const BaseWindow *dialog );
-
-static void          on_initial_load_dialog( NactAssistantImport *dialog, gpointer user_data );
-static void          on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data );
+static void          on_base_initialize_base_window( NactAssistantImport *dialog );
 static void          runtime_init_intro( NactAssistantImport *window, GtkAssistant *assistant );
 static void          runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant );
 static void          on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data );
@@ -153,7 +149,6 @@ class_init( NactAssistantImportClass *klass )
 {
 	static const gchar *thisfn = "nact_assistant_import_class_init";
 	GObjectClass *object_class;
-	BaseWindowClass *base_class;
 	BaseAssistantClass *assist_class;
 
 	g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -166,10 +161,6 @@ class_init( NactAssistantImportClass *klass )
 
 	klass->private = g_new0( NactAssistantImportClassPrivate, 1 );
 
-	base_class = BASE_WINDOW_CLASS( klass );
-	base_class->get_toplevel_name = window_get_dialog_name;
-	base_class->get_iprefs_window_id = window_get_iprefs_window_id;
-
 	assist_class = BASE_ASSISTANT_CLASS( klass );
 	assist_class->apply = assistant_apply;
 	assist_class->prepare = assistant_prepare;
@@ -181,28 +172,19 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "nact_assistant_import_instance_init";
 	NactAssistantImport *self;
 
+	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( instance ));
+
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( instance ));
+
 	self = NACT_ASSISTANT_IMPORT( instance );
 
 	self->private = g_new0( NactAssistantImportPrivate, 1 );
 
 	self->private->results = NULL;
 
-	base_window_signal_connect(
-			BASE_WINDOW( instance ),
-			G_OBJECT( instance ),
-			BASE_WINDOW_SIGNAL_INITIAL_LOAD,
-			G_CALLBACK( on_initial_load_dialog ));
-
-	base_window_signal_connect(
-			BASE_WINDOW( instance ),
-			G_OBJECT( instance ),
-			BASE_WINDOW_SIGNAL_RUNTIME_INIT,
-			G_CALLBACK( on_runtime_init_dialog ));
-
-	self->private->gconf = gconf_client_get_default();
+	base_window_signal_connect( BASE_WINDOW( instance ),
+			G_OBJECT( instance ), BASE_SIGNAL_INITIALIZE_WINDOW, G_CALLBACK( on_base_initialize_base_window ));
 
 	self->private->dispose_has_run = FALSE;
 }
@@ -213,16 +195,15 @@ instance_dispose( GObject *window )
 	static const gchar *thisfn = "nact_assistant_import_instance_dispose";
 	NactAssistantImport *self;
 
-	g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( window ));
+
 	self = NACT_ASSISTANT_IMPORT( window );
 
 	if( !self->private->dispose_has_run ){
+		g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
 
 		self->private->dispose_has_run = TRUE;
 
-		g_object_unref( self->private->gconf );
-
 		/* chain up to the parent class */
 		if( G_OBJECT_CLASS( st_parent_class )->dispose ){
 			G_OBJECT_CLASS( st_parent_class )->dispose( window );
@@ -236,8 +217,10 @@ instance_finalize( GObject *window )
 	static const gchar *thisfn = "nact_assistant_import_instance_finalize";
 	NactAssistantImport *self;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( window ));
+
+	g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
+
 	self = NACT_ASSISTANT_IMPORT( window );
 
 	free_results( self->private->results );
@@ -250,12 +233,6 @@ instance_finalize( GObject *window )
 	}
 }
 
-static NactAssistantImport *
-assist_new( BaseWindow *parent )
-{
-	return( g_object_new( NACT_ASSISTANT_IMPORT_TYPE, BASE_WINDOW_PROP_PARENT, parent, NULL ));
-}
-
 /**
  * nact_assistant_import_run:
  * @main: the #NactMainWindow parent window of this assistant.
@@ -265,57 +242,39 @@ assist_new( BaseWindow *parent )
 void
 nact_assistant_import_run( BaseWindow *main_window )
 {
-	NactAssistantImport *assist;
-
-	assist = assist_new( main_window );
-	g_object_set( G_OBJECT( assist ), BASE_WINDOW_PROP_HAS_OWN_BUILDER, TRUE, NULL );
-
-	base_window_run( BASE_WINDOW( assist ));
-}
-
-static gchar *
-window_get_iprefs_window_id( const BaseWindow *window )
-{
-	return( g_strdup( "import-assistant" ));
-}
-
-static gchar *
-window_get_dialog_name( const BaseWindow *dialog )
-{
-	return( g_strdup( "ImportAssistant" ));
-}
-
-static void
-on_initial_load_dialog( NactAssistantImport *dialog, gpointer user_data )
-{
-	static const gchar *thisfn = "nact_assistant_import_on_initial_load_dialog";
-	NactApplication *application;
-	NAUpdater *updater;
+	NactAssistantImport *assistant;
 	gboolean esc_quit, esc_confirm;
 
-	g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
-	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( dialog ));
+	g_return_if_fail( NACT_IS_MAIN_WINDOW( main_window ));
 
-	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( dialog )));
-	updater = nact_application_get_updater( application );
-	esc_quit = na_iprefs_read_bool( NA_IPREFS( updater ), IPREFS_ASSIST_ESC_QUIT, TRUE );
-	base_assistant_set_cancel_on_esc( BASE_ASSISTANT( dialog ), esc_quit );
-	esc_confirm = na_iprefs_read_bool( NA_IPREFS( updater ), IPREFS_ASSIST_ESC_CONFIRM, TRUE );
-	base_assistant_set_warn_on_esc( BASE_ASSISTANT( dialog ), esc_confirm );
+	esc_quit = na_settings_get_boolean( NA_IPREFS_ASSISTANT_ESC_QUIT, NULL, NULL );
+	esc_confirm = na_settings_get_boolean( NA_IPREFS_ASSISTANT_ESC_CONFIRM, NULL, NULL );
+
+	assistant = g_object_new( NACT_ASSISTANT_IMPORT_TYPE,
+			BASE_PROP_PARENT,          main_window,
+			BASE_PROP_HAS_OWN_BUILDER, TRUE,
+			BASE_PROP_XMLUI_FILENAME,  st_xmlui_filename,
+			BASE_PROP_TOPLEVEL_NAME,   st_toplevel_name,
+			BASE_PROP_WSP_NAME,        st_wsp_name,
+			BASE_PROP_QUIT_ON_ESCAPE,  esc_quit,
+			BASE_PROP_WARN_ON_ESCAPE,  esc_confirm,
+			NULL );
+
+	base_window_run( BASE_WINDOW( assistant ));
 }
 
 static void
-on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data )
+on_base_initialize_base_window( NactAssistantImport *dialog )
 {
-	static const gchar *thisfn = "nact_assistant_import_on_runtime_init_dialog";
+	static const gchar *thisfn = "nact_assistant_import_on_base_initialize_base_window";
 	GtkAssistant *assistant;
 
-	g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( dialog ));
 
 	if( !dialog->private->dispose_has_run ){
+		g_debug( "%s: dialog=%p", thisfn, ( void * ) dialog );
 
-		assistant = GTK_ASSISTANT( base_window_get_toplevel( BASE_WINDOW( dialog )));
+		assistant = GTK_ASSISTANT( base_window_get_gtk_toplevel( BASE_WINDOW( dialog )));
 
 		runtime_init_intro( dialog, assistant );
 		runtime_init_file_selector( dialog, assistant );
@@ -341,8 +300,6 @@ static void
 runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant )
 {
 	static const gchar *thisfn = "nact_assistant_import_runtime_init_file_selector";
-	NactApplication *application;
-	NAUpdater *updater;
 	GtkWidget *page;
 	GtkWidget *chooser;
 	gchar *uri;
@@ -352,11 +309,8 @@ runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
-	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-	updater = nact_application_get_updater( application );
-
 	chooser = base_window_get_widget( BASE_WINDOW( window ), "ImportFileChooser" );
-	uri = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_IMPORT_ITEMS_FOLDER_URI, "file:///tmp" );
+	uri = na_settings_get_string( NA_IPREFS_IMPORT_ASSISTANT_URI, NULL, NULL );
 	if( uri && strlen( uri )){
 		gtk_file_chooser_set_current_folder_uri( GTK_FILE_CHOOSER( chooser ), uri );
 	}
@@ -374,9 +328,6 @@ runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant
 static void
 on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 {
-	/*static const gchar *thisfn = "nact_assistant_import_on_file_selection_changed";
-	g_debug( "%s: chooser=%p, user_data=%p", thisfn, chooser, user_data );*/
-
 	GtkAssistant *assistant;
 	gint pos;
 	GSList *uris;
@@ -385,7 +336,7 @@ on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 	GtkWidget *content;
 
 	g_assert( NACT_IS_ASSISTANT_IMPORT( user_data ));
-	assistant = GTK_ASSISTANT( base_window_get_toplevel( BASE_WINDOW( user_data )));
+	assistant = GTK_ASSISTANT( base_window_get_gtk_toplevel( BASE_WINDOW( user_data )));
 	pos = gtk_assistant_get_current_page( assistant );
 	if( pos == ASSIST_PAGE_FILES_SELECTION ){
 
@@ -394,7 +345,7 @@ on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 
 		if( enabled ){
 			folder = gtk_file_chooser_get_current_folder_uri( GTK_FILE_CHOOSER( chooser ));
-			nact_iprefs_write_string( BASE_WINDOW( user_data ), IPREFS_IMPORT_ITEMS_FOLDER_URI, folder );
+			na_settings_set_string( NA_IPREFS_IMPORT_ASSISTANT_URI, folder );
 			g_free( folder );
 		}
 
@@ -471,7 +422,7 @@ runtime_init_duplicates( NactAssistantImport *window, GtkAssistant *assistant )
 
 	g_debug( "%s: window=%p", thisfn, ( void * ) window );
 
-	mode = na_iprefs_get_import_mode( window->private->gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE );
+	mode = na_iprefs_get_import_mode( NA_IPREFS_IMPORT_PREFERRED_MODE, NULL );
 	set_import_mode( window, mode );
 
 	page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_DUPLICATES );
@@ -663,6 +614,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	NAImporterResult *result;
 	NactApplication *application;
 	NAUpdater *updater;
+	NactTreeView *items_view;
 
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( wnd ));
 
@@ -672,8 +624,8 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	imported_items = NULL;
 	memset( &import_parms, '\0', sizeof( NAImporterParms ));
 
-	g_object_get( G_OBJECT( wnd ), BASE_WINDOW_PROP_PARENT, &main_window, NULL );
-	import_parms.parent = base_window_get_toplevel( main_window );
+	g_object_get( G_OBJECT( wnd ), BASE_PROP_PARENT, &main_window, NULL );
+	import_parms.parent = base_window_get_gtk_toplevel( main_window );
 
 	chooser = base_window_get_widget( BASE_WINDOW( window ), "ImportFileChooser" );
 	import_parms.uris = gtk_file_chooser_get_uris( GTK_FILE_CHOOSER( chooser ));
@@ -690,7 +642,6 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 		result = ( NAImporterResult * ) it->data;
 
 		if( result->imported ){
-			na_object_check_status( result->imported );
 			imported_items = g_list_prepend( imported_items, result->imported );
 		}
 	}
@@ -700,16 +651,22 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 
 	/* then insert the list
 	 * assuring that actions will be inserted in the same order as uris
+	 *
+	 * the tree view (and its underlying tree store) takes a new reference
+	 * on the inserted objects; the pointers so remain valid even after
+	 * having released the imported_items list
 	 */
 	imported_items = g_list_reverse( imported_items );
-	nact_iactions_list_bis_insert_items( NACT_IACTIONS_LIST( main_window ), imported_items, NULL );
-	na_object_unref_items( imported_items );
+	items_view = nact_main_window_get_items_view( NACT_MAIN_WINDOW( main_window ));
+	nact_tree_ieditable_insert_items( NACT_TREE_IEDITABLE( items_view ), imported_items, NULL );
+	na_object_free_items( imported_items );
 }
 
 static NAObjectItem *
 check_for_existence( const NAObjectItem *item, NactMainWindow *window )
 {
 	static const gchar *thisfn = "nact_assistant_import_check_for_existence";
+	NactTreeView *items_view;
 	NAObjectItem *exists;
 	gchar *importing_id;
 
@@ -717,7 +674,8 @@ check_for_existence( const NAObjectItem *item, NactMainWindow *window )
 	g_debug( "%s: item=%p (%s), importing_id=%s",
 			thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ), importing_id );
 
-	exists = nact_main_window_get_item( window, importing_id );
+	items_view = nact_main_window_get_items_view( window );
+	exists = nact_tree_view_get_item_by_id( items_view, importing_id );
 
 	g_free( importing_id );
 
@@ -813,11 +771,10 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 	g_object_unref( title_tag );
 
 	mode = get_import_mode( window );
-	na_iprefs_set_import_mode( window->private->gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE, mode );
+	na_iprefs_set_import_mode( NA_IPREFS_IMPORT_PREFERRED_MODE, mode );
 
 	gtk_assistant_set_page_complete( assistant, page, TRUE );
-	base_assistant_set_warn_on_cancel( BASE_ASSISTANT( window ), FALSE );
-	base_assistant_set_warn_on_esc( BASE_ASSISTANT( window ), FALSE );
+	g_object_set( G_OBJECT( window ), BASE_PROP_WARN_ON_ESCAPE, FALSE, NULL );
 }
 
 static void
